import { z } from 'zod';
declare const FleetHelmBlock: z.ZodObject<{
    chart: z.ZodOptional<z.ZodString>;
    repo: z.ZodOptional<z.ZodString>;
    version: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    chart?: string | undefined;
    repo?: string | undefined;
    version?: string | undefined;
}, {
    chart?: string | undefined;
    repo?: string | undefined;
    version?: string | undefined;
}>;
export type FleetHelmBlock = z.infer<typeof FleetHelmBlock>;
/**
  Represent a GitRepo Kubernetes manifest of Fleet.
  @link https://fleet.rancher.io/gitrepo-add/#create-gitrepo-instance
 */
export declare const GitRepo: z.ZodObject<{
    metadata: z.ZodObject<{
        name: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        name: string;
    }, {
        name: string;
    }>;
    kind: z.ZodString;
    spec: z.ZodObject<{
        repo: z.ZodOptional<z.ZodString>;
        revision: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        repo?: string | undefined;
        revision?: string | undefined;
    }, {
        repo?: string | undefined;
        revision?: string | undefined;
    }>;
}, "strip", z.ZodTypeAny, {
    metadata: {
        name: string;
    };
    kind: string;
    spec: {
        repo?: string | undefined;
        revision?: string | undefined;
    };
}, {
    metadata: {
        name: string;
    };
    kind: string;
    spec: {
        repo?: string | undefined;
        revision?: string | undefined;
    };
}>;
export type GitRepo = z.infer<typeof GitRepo>;
/**
 Represent a Bundle configuration of Fleet, which is located in `fleet.yaml` files.
 @link https://fleet.rancher.io/gitrepo-structure/#fleetyaml
 */
export declare const FleetFile: z.ZodObject<{
    helm: z.ZodObject<{
        version: z.ZodOptional<z.ZodString>;
        repo: z.ZodOptional<z.ZodString>;
        chart: z.ZodOptional<z.ZodString>;
        releaseName: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        releaseName: string;
        version?: string | undefined;
        repo?: string | undefined;
        chart?: string | undefined;
    }, {
        releaseName: string;
        version?: string | undefined;
        repo?: string | undefined;
        chart?: string | undefined;
    }>;
    targetCustomizations: z.ZodOptional<z.ZodArray<z.ZodObject<{
        name: z.ZodString;
        helm: z.ZodOptional<z.ZodObject<{
            chart: z.ZodOptional<z.ZodOptional<z.ZodString>>;
            repo: z.ZodOptional<z.ZodOptional<z.ZodString>>;
            version: z.ZodOptional<z.ZodOptional<z.ZodString>>;
        }, "strip", z.ZodTypeAny, {
            chart?: string | undefined;
            repo?: string | undefined;
            version?: string | undefined;
        }, {
            chart?: string | undefined;
            repo?: string | undefined;
            version?: string | undefined;
        }>>;
    }, "strip", z.ZodTypeAny, {
        name: string;
        helm?: {
            chart?: string | undefined;
            repo?: string | undefined;
            version?: string | undefined;
        } | undefined;
    }, {
        name: string;
        helm?: {
            chart?: string | undefined;
            repo?: string | undefined;
            version?: string | undefined;
        } | undefined;
    }>, "many">>;
}, "strip", z.ZodTypeAny, {
    helm: {
        releaseName: string;
        version?: string | undefined;
        repo?: string | undefined;
        chart?: string | undefined;
    };
    targetCustomizations?: {
        name: string;
        helm?: {
            chart?: string | undefined;
            repo?: string | undefined;
            version?: string | undefined;
        } | undefined;
    }[] | undefined;
}, {
    helm: {
        releaseName: string;
        version?: string | undefined;
        repo?: string | undefined;
        chart?: string | undefined;
    };
    targetCustomizations?: {
        name: string;
        helm?: {
            chart?: string | undefined;
            repo?: string | undefined;
            version?: string | undefined;
        } | undefined;
    }[] | undefined;
}>;
export type FleetFile = z.infer<typeof FleetFile>;
export {};
